
# THIS FILE IS GENERATED FROM PYRAD_PROC SETUP.PY
short_version = '1.3.0'
version = '1.3.0'
full_version = '1.3.0'
git_revision = 'da62951bd659a692b906e440fef752b356b07b43'
compile_date_time = '2022-08-08 08:40'
username = 'wolfensb'
release = True

if not release:
    version = full_version
